pub fn load_model<B: Backend>(device: &B::Device) -> Option<NeuralCompilerV2<B>>Expand description
Load the trained model once, for use with compile_with_model.
Returns None if no checkpoint exists.
pub fn load_model<B: Backend>(device: &B::Device) -> Option<NeuralCompilerV2<B>>Load the trained model once, for use with compile_with_model.
Returns None if no checkpoint exists.