pub fn pull_into_codebase(
codebase: &mut Codebase,
client: &RegistryClient,
name_or_hash: &str,
) -> Result<PullResult, String>Expand description
Pull a definition from a registry into the local store.
pub fn pull_into_codebase(
codebase: &mut Codebase,
client: &RegistryClient,
name_or_hash: &str,
) -> Result<PullResult, String>Pull a definition from a registry into the local store.