pub struct SolverResult {
pub constraints_checked: usize,
pub rounds: usize,
pub counterexamples: Vec<Counterexample>,
pub always_satisfied: Vec<usize>,
pub unevaluable: Vec<usize>,
pub all_passed: bool,
}Expand description
Result of solving/checking a constraint system.
Fields
constraints_checked: usizeNumber of constraints checked.
rounds: usizeNumber of test rounds performed.
counterexamples: Vec<Counterexample>Counterexamples found (violated constraints).
always_satisfied: Vec<usize>Indices of constraints that were satisfied in all rounds (candidate tautologies).
unevaluable: Vec<usize>Indices of constraints that could not be evaluated (insufficient info).
all_passed: boolWhether all evaluable constraints passed in all rounds.
Implementations
Sourceimpl SolverResult
impl SolverResult
pub fn format_report(&self) -> String